﻿using Un4seen.Bass.Misc;

namespace WpfAudioPlayer.Models.Audio
{
	/// <summary>
	/// 音声のディレイ効果を提供します。
	/// </summary>
	class EffectDelay : IEffect
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public EffectDelay( int stream )
		{
			this._effector = new DSP_IIRDelay( stream, 0, 2f );
		}

		#region プロパティ

		/// <summary>
		/// サンプリング数を取得または設定します。
		/// </summary>
		public int Delay
		{
			get
			{
				return this._effector.Delay;
			}
			set
			{
				this._effector.Delay = value;
			}
		}

		/// <summary>
		/// 効果音をフィードバックさせる比率を取得または設定します。
		/// </summary>
		public double Feedback
		{
			get
			{
				return this._effector.Feedback;
			}
			set
			{
				this._effector.Feedback = value;
			}
		}

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分を取得または設定します。
		/// </summary>
		public double WetDry
		{
			get
			{
				return this._effector.WetDry;
			}
			set
			{
				this._effector.WetDry = value;
			}
		}

		#endregion

		#region 定数

		/// <summary>
		/// サンプリング数の既定値。
		/// </summary>
		public const int DefaultDelay = 4096;

		/// <summary>
		/// 効果音をフィードバックさせる比率の既定値。
		/// </summary>
		public const double DefaultFeedback = 0.5;

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分の既定値。
		/// </summary>
		public const double DefaultWetDry = 0.5;

		#endregion

		#region フィールド

		/// <summary>
		/// 音響効果。
		/// </summary>
		private DSP_IIRDelay _effector;

		#endregion

		#region IEffect メンバ

		/// <summary>
		/// 音響効果が有効である事を示す値を取得または設定します。
		/// </summary>
		public bool IsEnabled
		{
			get
			{
				return !this._effector.IsBypassed;
	
			}
			set
			{
				this._effector.SetBypass( !value );
			}
		}

		#endregion
	}
}
