﻿using Un4seen.Bass.Misc;

namespace WpfAudioPlayer.Models.Audio
{
	/// <summary>
	/// 音声のワイド効果を提供します。
	/// </summary>
	class EffectWide : IEffect
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public EffectWide( int stream )
		{
			this._effector = new DSP_StereoEnhancer( stream, 0 );
		}

		#region プロパティ

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分を取得または設定します。
		/// </summary>
		public double WetDry
		{
			get
			{
				return this._effector.WetDry;
			}
			set
			{
				this._effector.WetDry = value;
			}
		}

		/// <summary>
		/// 音の広がりを取得または設定します。
		/// </summary>
		public double Wide
		{
			get
			{
				return this._effector.WideCoeff;
			}
			set
			{
				this._effector.WideCoeff = value;
			}
		}

		#endregion

		#region 定数

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分の既定値。
		/// </summary>
		public const double DefaultWetDry = 0.5;

		/// <summary>
		/// 音の広がりの既定値。
		/// </summary>
		public const double DefaultWide = 2.0;

		#endregion

		#region フィールド

		/// <summary>
		/// 音響効果。
		/// </summary>
		private DSP_StereoEnhancer _effector;

		#endregion

		#region IEffect メンバ

		/// <summary>
		/// 音響効果が有効である事を示す値を取得または設定します。
		/// </summary>
		public bool IsEnabled
		{
			get
			{
				return !this._effector.IsBypassed;

			}
			set
			{
				this._effector.SetBypass( !value );
			}
		}

		#endregion
	}
}
