﻿using System;

namespace WpfAudioPlayer.Models.Wmf
{
	/// <summary>
	/// メタデータ属性の型を定義した列挙体。
	/// </summary>
	enum WMT_ATTR_DATATYPE
	{
		/// <summary>
		/// 4 バイトの整数。
		/// </summary>
		WMT_TYPE_DWORD = 0,

		/// <summary>
		/// NULL 文字終端の Unicode 文字列。
		/// </summary>
		WMT_TYPE_STRING = 1,

		/// <summary>
		/// バイト配列。
		/// </summary>
		WMT_TYPE_BINARY = 2,

		/// <summary>
		/// 4 バイトの真偽値。
		/// </summary>
		WMT_TYPE_BOOL = 3,

		/// <summary>
		/// 8 バイトの整数。
		/// </summary>
		WMT_TYPE_QWORD = 4,

		/// <summary>
		/// 2 バイトの整数。
		/// </summary>
		WMT_TYPE_WORD = 5,

		/// <summary>
		/// 128 ビット ( 6 バイト ) の GUID ( Global Unique Identifier ) 値。
		/// </summary>
		WMT_TYPE_GUID = 6,
	}

	/// <summary>
	/// The WMT_STREAM_SELECTION enumeration type defines the playback status of a stream.
	/// </summary>
	enum WMT_STREAM_SELECTION
	{
		/// <summary>
		/// No samples will be delivered for the stream.
		/// </summary>
		WMT_OFF = 0,

		/// <summary>
		/// Only samples with cleanpoints will be delivered for the stream.
		/// </summary>
		WMT_CLEANPOINT_ONLY = 1,

		/// <summary>
		/// All samples will be delivered for the stream.
		/// </summary>
		WMT_ON = 2,
	}
	
	/// <summary>
	/// The WMT_RIGHTS enumeration type defines the rights that may be specified in a DRM license.
	/// </summary>
	[Flags]
	enum WMT_RIGHTS : uint
	{
		/// <summary>
		/// This rigth is not defined in the WMF SDK, I added it to
		/// play files with no DRM
		/// </summary>
		WMT_RIGHT_NO_DRM = 0x00000000,

		/// <summary>
		/// Specifies the right to play content without restriction.
		/// </summary>
		WMT_RIGHT_PLAYBACK = 0x00000001,

		/// <summary>
		/// Specifies the right to copy content to a device not compliant with the Secure Digital Music Initiative (SDMI).
		/// </summary>
		WMT_RIGHT_COPY_TO_NON_SDMI_DEVICE = 0x00000002,

		/// <summary>
		/// Specifies the right to copy content to a CD.
		/// </summary>
		WMT_RIGHT_COPY_TO_CD = 0x00000008,

		/// <summary>
		/// Specifies the right to copy content to a device compliant with the Secure Digital Music Initiative (SDMI).
		/// </summary>
		WMT_RIGHT_COPY_TO_SDMI_DEVICE = 0x00000010,

		/// <summary>
		/// Specifies the right to play content one time only.
		/// </summary>
		WMT_RIGHT_ONE_TIME = 0x00000020,

		/// <summary>
		/// Specifies the right to save content from a server.
		/// </summary>
		WMT_RIGHT_SAVE_STREAM_PROTECTED = 0x00000040,

		/// <summary>
		/// Specifies the right to copy content.
		/// Windows Media DRM 10 regulates the devices to which the content can be copied by using output protection levels (OPLs).
		/// </summary>
		WMT_RIGHT_COPY = 0x00000080,

		/// <summary>
		/// Specifies the right to play content as part of an online scenario where multiple participants can contribute songs from their collection to a shared playlist.
		/// </summary>
		WMT_RIGHT_COLLABORATIVE_PLAY = 0x00000100,

		/// <summary>
		/// Reserved for future use. Do not use.
		/// </summary>
		WMT_RIGHT_SDMI_TRIGGER = 0x00010000,

		/// <summary>
		/// Reserved for future use. Do not use.
		/// </summary>
		WMT_RIGHT_SDMI_NOMORECOPIES = 0x00020000
	}

}
