﻿using WpfAudioPlayer.Models.Audio;

namespace WpfAudioPlayer.ViewModels
{
	/// <summary>
	/// 音声のディレイ効果の View と Model を仲介するクラスです。
	/// </summary>
	class EffectDelayViewModel : EffectViewModelBase 
	{
		#region EffectViewModelBase の実装

		/// <summary>
		/// ストリームに音響効果を割り当てます。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public override void Attach( int stream )
		{
			this._effect = new EffectDelay( stream ) { Feedback = this._feedback, Delay = this._delay, WetDry = this._wetDry, IsEnabled = this.IsEnabled };
			this.Effect = this._effect;
		}

		#endregion

		#region プロパティ

		/// <summary>
		/// サンプリング数を取得または設定します。
		/// </summary>
		public int Delay
		{
			get
			{
				return this._delay;
			}
			set
			{
				this._delay = value;
				if( this._effect != null )
				{
					this._effect.Delay = value;
				}

				this.NotifyPropertyChanged( "Level" );
			}
		}

		/// <summary>
		/// 効果音をフィードバックさせる比率を取得または設定します。
		/// </summary>
		public double Feedback
		{
			get
			{
				return this._feedback;
			}
			set
			{
				this._feedback = value;
				if( this._effect != null )
				{
					this._effect.Feedback = value;
				}

				this.NotifyPropertyChanged( "Feedback" );
			}
		}

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分を取得または設定します。
		/// </summary>
		public double WetDry
		{
			get
			{
				return this._wetDry;
			}
			set
			{
				this._wetDry = value;
				if( this._effect != null )
				{
					this._effect.WetDry = value;
				}

				this.NotifyPropertyChanged( "WetDry" );
			}
		}

		#endregion

		#region フィールド

		/// <summary>
		/// 音響効果。
		/// </summary>
		private EffectDelay _effect;

		/// <summary>
		/// サンプリング数。
		/// </summary>
		private int _delay = EffectDelay.DefaultDelay;

		/// <summary>
		/// 効果音をフィードバックさせる比率。
		/// </summary>
		private double _feedback = EffectDelay.DefaultFeedback;

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分。
		/// </summary>
		private double _wetDry = EffectDelay.DefaultWetDry;

		#endregion
	}
}
