﻿using WpfAudioPlayer.Models.Audio;

namespace WpfAudioPlayer.ViewModels
{
	/// <summary>
	/// 音声のディストーション効果の View と Model を仲介するクラスです。
	/// </summary>
	class EffectDistortionViewModel : EffectViewModelBase
	{
		#region EffectViewModelBase の実装

		/// <summary>
		/// ストリームに音響効果を割り当てます。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public override void Attach( int stream )
		{
			this._effect = new EffectDistortion( stream ) { Edge = this._edge, Gain = this._gain, PostEqBandWidth = this._postEqBandWidth, PostEqCenterFrequency = this._postEqCenterFrequency, PreLowPassCutOff = this._preLowPassCutOff, IsEnabled = this.IsEnabled };
			this.Effect = this._effect;
		}

		#endregion

		#region プロパティ

		/// <summary>
		/// 歪みの強さを取得または設定します。
		/// </summary>
		public float Edge
		{
			get
			{
				return this._edge;
			}
			set
			{
				this._edge = value;
				if( this._effect != null )
				{
					this._effect.Edge = value;
				}

				this.NotifyPropertyChanged( "Edge" );
			}
		}

		/// <summary>
		/// 歪みを掛けた時の信号の変化量を取得または設定します。
		/// </summary>
		public float Gain
		{
			get
			{
				return this._gain;
			}
			set
			{
				this._gain = value;
				if( this._effect != null )
				{
					this._effect.Gain = value;
				}

				this.NotifyPropertyChanged( "Gain" );
			}
		}

		/// <summary>
		/// 高調波成分の範囲を取得または設定します。
		/// </summary>
		public float PostEqBandWidth
		{
			get
			{
				return this._postEqBandWidth;
			}
			set
			{
				this._postEqBandWidth = value;
				if( this._effect != null )
				{
					this._effect.PostEqBandWidth = value;
				}

				this.NotifyPropertyChanged( "PostEqBandWidth" );
			}
		}

		/// <summary>
		/// 中心周波数の範囲を取得または設定します。
		/// </summary>
		public float PostEqCenterFrequency
		{
			get
			{
				return this._postEqCenterFrequency;
			}
			set
			{
				this._postEqCenterFrequency = value;
				if( this._effect != null )
				{
					this._effect.PostEqCenterFrequency = value;
				}

				this.NotifyPropertyChanged( "PostEqCenterFrequency" );
			}
		}

		/// <summary>
		/// 減衰フィルタの範囲を取得または設定します。
		/// </summary>
		public float PreLowPassCutOff
		{
			get
			{
				return this._preLowPassCutOff;
			}
			set
			{
				this._preLowPassCutOff = value;
				if( this._effect != null )
				{
					this._effect.PreLowPassCutOff = value;
				}

				this.NotifyPropertyChanged( "PreLowPassCutOff" );
			}
		}

		#endregion
		
		#region フィールド

		/// <summary>
		/// 音響効果。
		/// </summary>
		private EffectDistortion _effect;

		/// <summary>
		/// 歪みの強さ。
		/// </summary>
		private float _edge = EffectDistortion.DefaultEdge;

		/// <summary>
		/// 歪みを掛けた時の信号の変化量。
		/// </summary>
		private float _gain = EffectDistortion.DefaultGain;

		/// <summary>
		/// 高調波成分の範囲。
		/// </summary>
		private float _postEqBandWidth = EffectDistortion.DefaultPostEqBandWidth;

		/// <summary>
		/// 中心周波数の範囲。
		/// </summary>
		private float _postEqCenterFrequency = EffectDistortion.DefaultPostEqCenterFrequency;

		/// <summary>
		/// 減衰フィルタの範囲。
		/// </summary>
		private float _preLowPassCutOff = EffectDistortion.DefaultPreLowPassCutOff;

		#endregion
	}
}
