﻿using WpfAudioPlayer.Models.Audio;

namespace WpfAudioPlayer.ViewModels
{
	/// <summary>
	/// 音声のエコー効果の View と Model を仲介するクラスです。
	/// </summary>
	class EffectEchoViewModel : EffectViewModelBase
	{
		#region EffectViewModelBase の実装

		/// <summary>
		/// ストリームに音響効果を割り当てます。
		/// </summary>
		/// <param name="stream">ストリームの識別子。</param>
		public override void Attach( int stream )
		{
			this._effect = new EffectEcho( stream ) { Feedback = this._feedback, LeftDelay = this._leftDelay, RightDelay = this._rightDelay, WetDryMix = this._wetDryMix, IsEnabled = this.IsEnabled };
			this.Effect = this._effect;
		}

		#endregion

		#region プロパティ

		/// <summary>
		/// 効果音をフィードバックさせる比率を取得または設定します。
		/// </summary>
		public float Feedback
		{
			get
			{
				return this._feedback;
			}
			set
			{
				this._feedback = value;
				if( this._effect != null )
				{
					this._effect.Feedback = value;
				}

				this.NotifyPropertyChanged( "Feedback" );
			}
		}

		/// <summary>
		/// 左チャンネルの音声の遅延時間を取得または設定します。
		/// </summary>
		public float LeftDelay
		{
			get
			{
				return this._leftDelay;
			}
			set
			{
				this._leftDelay = value;
				if( this._effect != null )
				{
					this._effect.LeftDelay = value;
				}

				this.NotifyPropertyChanged( "LeftDelay" );
			}
		}

		/// <summary>
		/// 左チャンネルの音声の遅延時間を取得または設定します。
		/// </summary>
		public float RightDelay
		{
			get
			{
				return this._rightDelay;
			}
			set
			{
				this._rightDelay = value;
				if( this._effect != null )
				{
					this._effect.RightDelay = value;
				}

				this.NotifyPropertyChanged( "RightDelay" );
			}
		}

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分を取得または設定します。
		/// </summary>
		public float WetDryMix
		{
			get
			{
				return this._wetDryMix;
			}
			set
			{
				this._wetDryMix = value;
				if( this._effect != null )
				{
					this._effect.WetDryMix = value;
				}

				this.NotifyPropertyChanged( "WetDryMix" );
			}
		}

		#endregion
		
		#region フィールド

		/// <summary>
		/// 音響効果。
		/// </summary>
		private EffectEcho _effect;

		/// <summary>
		/// 効果音音をフィードバックさせる比率。
		/// </summary>
		private float _feedback = EffectEcho.DefaultFeedback;

		/// <summary>
		/// 左チャンネルの音声の遅延時間を取得または設定します。
		/// </summary>
		private float _leftDelay = EffectEcho.DefaultLeftDelay;

		/// <summary>
		/// 右チャンネルの音声の遅延時間を取得または設定します。
		/// </summary>
		private float _rightDelay = EffectEcho.DefaultRightDelay;

		/// <summary>
		/// 効果音 ( Wet ) と原音 ( Dry ) の配分。
		/// </summary>
		private float _wetDryMix = EffectEcho.DefaultWetDryMix;

		#endregion
	}
}
